@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -47,12 +47,6 @@ has lowercase => (
 );
 
 
-has digits => (
-    is      => 'ro',
-    default => sub { 0 },
-);
-
-
 has counts => (
     is       => 'ro',
     init_arg => undef,
@@ -98,10 +92,8 @@ sub _process_ngrams {
         my $pat = $self->punctuation;
         $p =~ s/$pat//g if $pat; # Remove unwanted punctuation
 
-        $p =~ s/\d//g if $self->digits; # Remove unwanted digits
-
         # Skip if we don't have an ngram of the requested size anymore
-        my @p = grep { $_ } split /\s/, $p;
+        my @p = grep { $_ } split /\s+/, $p;
         next unless @p == $size;
 
         # Skip a lone single quote (allowed by the default punctuation)
@@ -181,7 +173,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0402
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -233,10 +225,6 @@ Note that the default does not exclude the single quote.
 
 Boolean to render the ngrams in lowercase.  Default is 0.
 
-=head2 digits
-
-Boolean to exclude digits from the ngram results.  Default is 0.
-
 =head2 counts
 
 HashRef of the ngram counts of each processed file.  This is a computed
